;+
; NAME:
;	DO_MAP_SCAN
;
; PURPOSE:
;
;	Create a map (in array coordinates) for a given subscan.	
;
; CALLING SEQUENCE:
;
;	DO_MAP_SCAN, Datastr, Positions, Map_out_dim, Carte_scan
;
; INPUTS:
;
;	Datastr:	Input data structure.
;	Positions:	Coordinates in pixel image.	
;
; OPTIONAL INPUTS:
;
;	Echant:		Rebin factor.
;	Dx_rcp:		Pixels offsets in x direction.
;	Dy_rcp:		Pixels offsets in y direction.	
;	
; KEYWORD PARAMETERS:
;
;	DO_RCP:		Use distorsion files. 
;
; OUTPUTS:
;
;	Map_out_dim:	Rebined map dimensions.
;	Carte_scan:	Subscan map.
;
; COMMON BLOCKS:
;
;	OBS1_CONFIGB:	Contains working directory, project name and calibration
;			file.
;
; EXAMPLE:
;
;		DO_MAP_SCAN, Donnees_red, Positions, Out_ima_dim, Echant=3, Dx_rcp=Dx_rcp, Dy_rcp=Dy_rcp, /DO_RCP, Carte_scan
;
; MODIFICATION HISTORY:
;
;-

pro do_map_scan, datastr, positions, map_out_dim, echant=echant, dx_rcp=dx_rcp, dy_rcp=dy_rcp, do_rcp=do_rcp, carte_scan


if n_params() eq 0 then begin
	print, 'Calling sequence :'
	print, '	DO_MAP_SCAN, Datastr, Positions, Map_out_dim, Echant= Echant, Dx_rcp= Dx_rcp, Dy_rcp= Dy_rcp, Do_rcp= Do_rcp, Carte_scan'
	return
endif	


;create a map for a given subscan

COMMON obs1_configb

; set_pos_  calcule le tableau "positions" (npairwobb) contenant les coordonnees
; x0,y0 du pixel (0,0) de la camera dans l'image re-echantillonnee de sortie
 

if keyword_set(do_rcp) eq 1 then begin 	

;;;pfov_ref=6.2
;;pfov_ref=3.9					;  Artemis 350
;pfov_ref = abs(datastr.cdelt2)*1.05
pfov_ref = abs(datastr.cdelt2)
fine_pix = pfov_ref/echant
						
 ;set_pos_, datastr, echant=echant, positions, map_out_dim, /do_rcp         ; on tient compte de la distorsion optique
 set_pos_, datastr, echant=echant*abs(datastr.cdelt1)/pfov_ref, positions, map_out_dim, /do_rcp 
endif else begin
;
 fine_pix = abs(datastr.cdelt2)/echant				; pixel size (arcsec) in the final rebinned image
; 
 set_pos_, datastr, echant=echant, positions, map_out_dim
endelse

;;;;;

; 350 microns focal plane : 64 x 36 = 2304 pixels in ArTeMiS350 but only 32 x 36 = 1152 pixels are used in 2013.
n_channel_x = 73      ; including 3*3 fake pixels between subarrays
n_channel_y = 39      ; including 3 fake pixels between subarrays

npix_eff = 73L*39L    ; including gaps

nx_chan = indgen(n_channel_x)#(transpose(intarr(n_channel_y))+1)
ny_chan = (intarr(n_channel_x)+1)#transpose(indgen(n_channel_y))

n_jun14 = 8

mask_jun14 = intarr(n_channel_x,n_channel_y)+1
mask_jun14(16:18,*) = 0
mask_jun14(35:37,*) = 0
mask_jun14(54:56,*) = 0
mask_jun14(*,18:20) = 0

mask_jun14_1 = mask_jun14*0
mask_jun14_1(0:15,0:17) = 1

mask_jun14_2 = mask_jun14*0
mask_jun14_2(19:34,0:17) = 1

mask_jun14_3 = mask_jun14*0
mask_jun14_3(38:53,0:17) = 1

mask_jun14_4 = mask_jun14*0
mask_jun14_4(57:72,0:17) = 1

mask_jun14_5 = mask_jun14*0
mask_jun14_5(0:15,21:38) = 1

mask_jun14_6 = mask_jun14*0
mask_jun14_6(19:34,21:38) = 1

mask_jun14_7 = mask_jun14*0
mask_jun14_7(38:53,21:38) = 1

mask_jun14_8 = mask_jun14*0
mask_jun14_8(57:72,21:38) = 1

mask_arr_jun14 = intarr(n_channel_x,n_channel_y,n_jun14)
;
mask_arr_jun14(*,*,0) = mask_jun14_1
mask_arr_jun14(*,*,1) = mask_jun14_2
mask_arr_jun14(*,*,2) = mask_jun14_3
mask_arr_jun14(*,*,3) = mask_jun14_4
;
mask_arr_jun14(*,*,4) = mask_jun14_5
mask_arr_jun14(*,*,5) = mask_jun14_6
mask_arr_jun14(*,*,6) = mask_jun14_7
mask_arr_jun14(*,*,7) = mask_jun14_8

;

x_off_arr = fltarr(n_jun14)
y_off_arr = fltarr(n_jun14)

;;;x_off_arr = [-0.48,0.0,-2.27,-2.04]					;  X offsets in arcsec for Artemis350 arrays # 2, 3, 6, 7
;;;y_off_arr = [+0.29,-1.55,-1.75,-1.95]					;  Y offsets in arcsec for Artemis350 arrays # 2, 3, 6, 7

;;x_off_arr = [0.00,-1.36333,-1.39333,-2.56667]				;  X offsets in arcsec for Artemis350 arrays # 2, 3, 6, 7
;;y_off_arr = [0.00,-1.62667,-1.44667,-1.79667]				;  Y offsets in arcsec for Artemis350 arrays # 2, 3, 6, 7

;x_off_arr = [0.00,-1.17640,-0.871841,-1.38456]				;  X offsets in arcsec for Artemis350 arrays # 2, 3, 6, 7
;y_off_arr = [0.00,-0.182409,-0.0318849,0.479938]			;  Y offsets in arcsec for Artemis350 arrays # 2, 3, 6, 7

;
;x_off_mask = x_off_arr(0)*mask_arr_jun14(*,*,0)+x_off_arr(1)*mask_arr_jun14(*,*,1)+x_off_arr(2)*mask_arr_jun14(*,*,2)+x_off_arr(3)*mask_arr_jun14(*,*,3)
;y_off_mask = y_off_arr(0)*mask_arr_jun14(*,*,0)+y_off_arr(1)*mask_arr_jun14(*,*,1)+y_off_arr(2)*mask_arr_jun14(*,*,2)+y_off_arr(3)*mask_arr_jun14(*,*,3)

;
x_off_arr = x_off_arr/fine_pix  				 	;  X offsets in units of fine pixels for Artemis350 arrays # 2, 3, 6, 7
y_off_arr = y_off_arr/fine_pix  				 	;  Y offsets in units of fine pixels for Artemis350 arrays # 2, 3, 6, 7

;;;;;
 
; indice de l'image du centre du scan et du temps sideral local associe
n_images = n_elements(datastr.datapar.azimuth)                  
id_ima_milieu = n_images/2                                       
datastr.lst_mid = datastr.lst(id_ima_milieu)
;print, "id_ima_milieu = ", id_ima_milieu


datastr.alpha_mid = datastr.datapar(id_ima_milieu).baslong
datastr.delta_mid = datastr.datapar(id_ima_milieu).baslat


; recherche de l'image dont le lst est le plus proche de lst_mid
;delta_lst = abs(datastr.lst - datastr.lst_mid)
;bidon = min(delta_lst, id_min_lst)
;print, "id_min_lst = ", id_min_lst
;
id_min_lst = id_ima_milieu

;delta_lst = datastr.lst(id_min_lst) - datastr.lst_mid
;delta_az = datastr.otfvlam*dlst2dtloc(delta_lst)

alpha_ref = datastr.alpha_mid
delta_ref = datastr.delta_mid


rms_noise = datastr.rmsmoy
cube = datastr.cube

taille = size(cube)
size_array1 = taille(1)
size_array2 = taille(2)

;ind = where(datastr.lst ne -999., cnt)						         ; eliminating data with unknown telescope positions

ind = where (datastr.datapar.longoff ne -999. and datastr.datapar.latoff ne -999., cnt)

if cnt eq 0 then begin
  
  print, "ERROR (do_map_scan): longoff and latoff are undefined (-999)"
  return

endif 

;npairwobb = min([taille(3),(size(datastr.datapar))(3)])
npairwobb = cnt

ndim = map_out_dim
npixrebin1 = size_array1*echant 
npixrebin2 = size_array2*echant 

image_finale = fltarr(ndim,ndim)
masque = fltarr(ndim,ndim)

weight = double(rms_noise*0.)		; 16x16 array (p-ArTeMiS) / n1xn2 array

index = where(rms_noise gt 0., count)
if (count gt 0) then begin
   weight(index) = 1.d0/rms_noise(index)^2
endif else begin
	print, 'WARNING   WARNING'
	print, '% DO_MAP_SCAN : rms noise = 0 pour tous les pixels ' 
	weight = weight +1
endelse

weight = weight * datastr.goodpix_ima

ind_nan = where(finite(weight,/NAN), cnt)
if cnt gt 0 then weight(ind_nan) = 0.

ind_nan = where(finite(cube,/NAN), cnt)
if cnt gt 0 then cube(ind_nan) = 0.

;;;  Flagging outlier detector pixels for current scan if source is not a planet
;
index_good = where(datastr.goodpix_ima gt 0 and rms_noise gt 0., count)
if (count gt 0) then rms_noise_med = median(rms_noise(index_good))    	; median rms_noise of good pixels for current subscan

if (count gt 0 and datastr.movefram eq 0) then begin
    index_bad = where(rms_noise lt rms_noise_med/5. or rms_noise gt rms_noise_med*5, count_bad)
    if (count_bad gt 0) then weight(index_bad) = 0.
endif
;
;;;

if keyword_set(do_rcp) EQ 0 then begin 
weight_rebin = rebin(weight, npixrebin1, npixrebin2, /sample)

cdelt1 = -datastr.cdelt1 / echant / 3600.     ; increment en degres	cdelt1 est negatif pour etre correct apres rotation vers RA-DEC
cdelt2 = -cdelt1

endif

if keyword_set(do_rcp) EQ 1 then begin 


cdelt1 = -pfov_ref / echant / 3600.     ; increment en degres	cdelt1 est negatif pour etre correct apres rotation vers RA-DEC
cdelt2 = -cdelt1

endif

crota1 = datastr.crota1

;;;;

mask_jun14_rebin = rebin(mask_jun14, npixrebin1, npixrebin2, /sample)

mask_arr_jun14_rebin = intarr(npixrebin1,npixrebin2,n_jun14)
;
mask_arr_jun14_rebin(*,*,0) = rebin(mask_jun14_1, npixrebin1, npixrebin2, /sample)
mask_arr_jun14_rebin(*,*,1) = rebin(mask_jun14_2, npixrebin1, npixrebin2, /sample)
mask_arr_jun14_rebin(*,*,2) = rebin(mask_jun14_3, npixrebin1, npixrebin2, /sample)
mask_arr_jun14_rebin(*,*,3) = rebin(mask_jun14_4, npixrebin1, npixrebin2, /sample)
;
mask_arr_jun14_rebin(*,*,0) = rebin(mask_jun14_5, npixrebin1, npixrebin2, /sample)
mask_arr_jun14_rebin(*,*,1) = rebin(mask_jun14_6, npixrebin1, npixrebin2, /sample)
mask_arr_jun14_rebin(*,*,2) = rebin(mask_jun14_7, npixrebin1, npixrebin2, /sample)
mask_arr_jun14_rebin(*,*,3) = rebin(mask_jun14_8, npixrebin1, npixrebin2, /sample)


;;;;
							; calcule maintenant dans traite_otf_scan
IF keyword_set(do_rcp) EQ 1 THEN BEGIN                 ; si l'on tient compte de la distorsion optique

;;;;;;

;dx_rcp_0 = dx_rcp
;dy_rcp_0 = dy_rcp

;dx_rcp = dx_rcp_0-x_off_mask
;dy_rcp = dy_rcp_0-y_off_mask

;;;;;;

;kern_size = 3
kern_size = 5
;kern_size = 7
;;kern_size = 9

x_kern0 = (indgen(kern_size)-kern_size/2)#((intarr(kern_size))+1)				; 3x3
y_kern0 = (intarr(kern_size)+1)#(indgen(kern_size)-kern_size/2)					; 3x3

x_kern_grid0 = x_kern0(0:kern_size^2-1)#(intarr(taille(1)*taille(2))+1)				;  9x(35*39)  ArTeMiS 350 Jul.2013
y_kern_grid0 = y_kern0(0:kern_size^2-1)#(intarr(taille(1)*taille(2))+1)


;ndim_sub = npixrebin+kern_size-echant+2							; P-Artemis
ndim_sub = max([npixrebin1,npixrebin2])+kern_size-echant+2					; Artemis WARNING   119 ~ 3*39

ind_kern0 = (intarr(kern_size)+1)#((indgen(kern_size)-kern_size/2)*ndim_sub) + (indgen(kern_size)-kern_size/2)#(intarr(kern_size)+1)

ind_kern0 = ind_kern0(0:kern_size^2-1)					; 9 array


x_r0 = dx_rcp(0:taille(1)*taille(2)-1)/cdelt2/3600. 				 		; in units of pixels of the resampled grid	n1xn2 (35x39 for ArTeMiS 350 Jul.2013)
y_r0 = dy_rcp(0:taille(1)*taille(2)-1)/cdelt2/3600. 


x_subim_cube0 = (fltarr((kern_size)*(kern_size))+1.)#x_r0					;  9x(35*39)  ArTeMiS 350 Jul.2013

y_subim_cube0 = (fltarr((kern_size)*(kern_size))+1.)#y_r0					;  9x(35*39)  ArTeMiS 350 Jul.2013



   FOR i=0,npairwobb-1 DO BEGIN

;	image = cube(*,*,i)
	image = cube(*,*,ind(i))

;     for k_arr = 0, n_jun14-1 do begin
;	x0_r = positions(i,0)+x_off_arr(k_arr)
;	y0_r = positions(i,1)+y_off_arr(k_arr)
	
	x0_r = positions(i,0)							; offsets of array center in units of pixels of the resampled grid
	y0_r = positions(i,1)


        x0_i = nint(x0_r)
	y0_i = nint(y0_r)

;;;;;;;;;;;;;;;;;;;;;;;;;;; ndim_sub = npixrebin+kern_size-echant + 2
		
;	x0 = x0_i - (echant*(taille(1)/2-1)+echant/2) - (kern_size-echant)/2 - 1	; extreme position of array's bottom left corner in resampled grid
;	y0 = y0_i - (echant*(taille(2)/2-1)+echant/2) - (kern_size-echant)/2 - 1	

       x0 = x0_i - (echant*(15)+echant/2) - (kern_size-echant)/2 - 1        ; extreme position of array's bottom left corner in resampled grid
       y0 = y0_i - (echant*(17)+echant/2) - (kern_size-echant)/2 - 1        

	x_r = x_r0 + x0_r 							; in units of pixels of the resampled grid	n1xn2 (35*39 array for ArTeMiS350 Jul2013)
	y_r = y_r0 + y0_r

	x_r_grid = x_subim_cube0 + x0_r									; 9x(35*39) array   (ArTeMiS350 Jul2013)
	y_r_grid = y_subim_cube0 + y0_r
	
	x_i = nint(x_r)											; (35*39) array   (ArTeMiS350 Jul2013)
	y_i = nint(y_r)	

	x_i_grid = (intarr((kern_size)*(kern_size))+1.)#x_i						; 9x(35*39) array   (ArTeMiS350 Jul2013)
	
	x_kern_grid = x_kern_grid0 + x_i_grid
	
	y_i_grid = (intarr((kern_size)*(kern_size))+1.)#y_i						; 9x(35*39) array   (ArTeMiS350 Jul2013)

	y_kern_grid = y_kern_grid0 + y_i_grid
	
	dx = (x_kern_grid - x_r_grid)*datastr.cdelt2/echant			; in arcsec      	  9x(35*39) array   (ArTeMiS350 Jul2013)
	dy = (y_kern_grid - y_r_grid)*datastr.cdelt2/echant

	dr =  sqrt(dx^2+dy^2)										; in arcsec
	att = grid_kernel(dr)                                                                           ;  9x(35*39) array   (ArTeMiS350 Jul2013)
;	att = grid_kernel_xy(dx,dy,fine_pix)                                                                           ;  9x(35*39) array   (ArTeMiS350 Jul2013)

	ind_subim = (y_i-y0)*ndim_sub + (x_i-x0)								;  n1xn2 array (35x39 array for ArTeMiS350 Jul2013)
	
	ind_subim = ind_subim(0:taille(1)*taille(2)-1)								;  35*39 array (ArTeMiS350 Jul2013)
	
	ind_grid = ind_kern0#(intarr(taille(1)*taille(2))+1) + (intarr(kern_size^2)+1)#ind_subim		;  9x(35*39) array  (ArTeMiS350 Jul2013)

	for k=0,kern_size^2-1 do begin
	
		subim_grid_k = fltarr(ndim_sub,ndim_sub)
		subim_grid_k(ind_grid(k,*)) = image(0:taille(1)*taille(2)-1)
		
		weight_subim_grid_k = fltarr(ndim_sub,ndim_sub)		
		weight_subim_grid_k(ind_grid(k,*)) = weight(0:taille(1)*taille(2)-1)*att(k,0:taille(1)*taille(2)-1)
;		weight_subim_grid_k(ind_grid(k,*)) = weight(0:taille(1)*taille(2)-1)*att(k,0:taille(1)*taille(2)-1)*mask_arr_jun14(*,*,k_arr)
		
		image_finale(x0:x0+ndim_sub-1,y0:y0+ndim_sub-1) = image_finale(x0:x0+ndim_sub-1,y0:y0+ndim_sub-1) + subim_grid_k*weight_subim_grid_k
     		masque(x0:x0+ndim_sub-1,y0:y0+ndim_sub-1) = masque(x0:x0+ndim_sub-1,y0:y0+ndim_sub-1) +  weight_subim_grid_k

	endfor
;     endfor
   ENDFOR        ; (0 to npairwobb-1)

ENDIF ELSE BEGIN    ; on ne tient pas compte de la distorsion optique (do_rcp = 0)

   for i=0,npairwobb-1 do begin
;	image = rebin(cube(*,*,i), npixrebin, npixrebin, /sample)
	image = rebin(cube(*,*,ind(i)), npixrebin1, npixrebin2, /sample)
;     for k_arr = 0, n_jun14-1 do begin							;  NB: positions is a npairwobb x 2 array defined by subroutine set_pos_ 
;	x0 = positions(i,0)+x_off_arr(k_arr)
;	y0 = positions(i,1)+y_off_arr(k_arr)
;	image_finale(x0:x0+npixrebin1-1,y0:y0+npixrebin2-1) = image_finale(x0:x0+npixrebin1-1,y0:y0+npixrebin2-1) + image*weight_rebin*mask_arr_jun14_rebin(*,*,k_arr)
;	masque(x0:x0+npixrebin1-1,y0:y0+npixrebin2-1) = masque(x0:x0+npixrebin1-1,y0:y0+npixrebin2-1) + weight_rebin*mask_arr_jun14_rebin(*,*,k_arr)
;    endfor
    	x0 = positions(i,0)
	y0 = positions(i,1)
        image_finale(x0:x0+npixrebin1-1,y0:y0+npixrebin2-1) = image_finale(x0:x0+npixrebin1-1,y0:y0+npixrebin2-1) + image*weight_rebin*mask_jun14_rebin
        masque(x0:x0+npixrebin1-1,y0:y0+npixrebin2-1) = masque(x0:x0+npixrebin1-1,y0:y0+npixrebin2-1) + weight_rebin*mask_jun14_rebin	
   endfor

ENDELSE   ;  (do_rcp)

xref0 = positions(id_min_lst, 0)                          ; pos. du pixel de reference dans la matrice non reechantillonee : (34,17) Artemis350 Jun2014 ; (15,17) Artemis350 Jul2013 <--> 559
yref0 = positions(id_min_lst, 1)


if keyword_set(do_rcp) EQ 1 then begin                    ; si l'on tient compte de la distorsion optique

xref = xref0
yref = yref0 

endif else begin

;xref = xref0 + echant*(taille(1)/2-1)+echant/2			; pixel de reference dans la matrice non reechantillonee : (34,17) Artemis350 Jun2014 <--> 559 ; (15,17) Artemis350 Jul2013 <--> 559
;yref = yref0 + echant*(taille(2)/2-1)+echant/2

;xref = xref0 + echant*15+echant/2
;yref = yref0 + echant*17+echant/2

xref = xref0 + echant*34+echant/2
yref = yref0 + echant*17+echant/2

endelse

dra_scan = -999
ddec_scan = -999
daz_scan = -999
del_scan = -999

IF datastr.scandir eq 'RA' THEN BEGIN                   ; scan en ascension droite

	; le pixel de l'image rebinnee (xref, yref) est en (alpha_ref, delta_ref) 
	;                                            et en (dra_scan, ddec_scan) par rapport a la source pointee
	; 	dra_scan et ddec_scan sont les offsets (en arcsec) du milieu du scan par rapport a la source pointee
	;

	dra_scan  = datastr.datapar(id_min_lst).longoff*3600.
	ddec_scan = datastr.datapar(id_min_lst).latoff*3600.

ENDIF ELSE BEGIN                                        ; scan en az

	; le pixel de l'image rebinnee (xref, yref) est en (alpha_ref, delta_ref) 
	;                                            et en (daz_scan, del_scan) par rapport a la source pointee
	;
	; 	daz_scan et del_scan sont les offsets (en arcsec) du milieu du scan par rapport a la source pointee
	;	(calculable a partir de lamdel, betdel, otfvlam et lst_mid)
	;
	;  daz_scan = datastr.lamdel + datastr.otfvlam*dlst2dtloc(datastr.lst_mid - datastr.lst(0))	; arcsec
	;  del_scan = datastr.betdel

	daz_scan = datastr.datapar(id_min_lst).longoff*3600.
	del_scan = datastr.datapar(id_min_lst).latoff*3600.

ENDELSE


map_out = image_finale*0
id = where(masque ne 0)
map_out(id) = image_finale(id)/masque(id)

ind_nan = where(finite(masque,/NAN), cnt)
if cnt gt 0 then masque(ind_nan) = 0. & map_out(ind_nan) = 0.

carte_scan = {filename :datastr.filename, image : map_out, weight : masque, crpix1 : xref, $
              crpix2 : yref, alpha_ref : alpha_ref, delta_ref : delta_ref, elevatio:datastr.elevatio, $
              cdelt1 : cdelt1, cdelt2 : cdelt2, crota1 : crota1, $
              scandir : datastr.scandir, dra_scan : dra_scan, ddec_scan:ddec_scan, $
	      daz_scan : daz_scan, del_scan : del_scan, source:datastr.source}

;stop
return
end	 
