; planet_artemis_rcp.pro: "Batch" IDL file 
;
; @obs1_artemis_config

; 350 microns focal plane : 64 x 36 = 2304 pixels in ArTeMiS350 but only 32 x 36 = 1152 pixels are used in 2013.
n_channel_x = 35      ; including 3 fake pixels between subarrays
n_channel_y = 39      ; including 3 fake pixels between subarrays

npix_eff = 35L*39L    ; including gaps

nx_chan = indgen(n_channel_x)#(transpose(intarr(n_channel_y))+1)
ny_chan = (intarr(n_channel_x)+1)#transpose(indgen(n_channel_y))

mask_jul13 = intarr(n_channel_x,n_channel_y)+1
mask_jul13(16:18,*) = 0
mask_jul13(*,18:20) = 0

ind_jul13 = where(mask_jul13 gt 0, nchan_eff)					;   1152 pixels

print, nchan_eff  			; Effective number of 350mu bolometer channels in 2013

; nchan_eff = 32*36	   		; Effective number of 350mu bolometer channels in 2013

;

init_obs, scan_number= 43041, type = 'map', init_obs_43041_str

traite_otf_map_main, scan_number= 43041, type = 'decorrel', neptune_decorrel_43011_str, tau=1.e-6

restore, '../../apexdata/map_otf_xdr/T-091.F-0008-2013/otf_subscan_43041_1.xdr', /verb

plot, donnees_red.cube(25,9,*)

print, (1/sqrt(40.))*stdev(donnees_red.cube(25,9,*))

taille = size(donnees.cube)

nefd = fltarr(taille(1),taille(2))

for j = 0, taille(2)-1 do begin & $
 for i = 0, taille(1)-1 do begin & $
  nefd(i,j) = (1/sqrt(40.))*stdev(donnees_red.cube(i,j,*)) & $
endfor

;

atv, nefd*goodpix_ima_3539

;
index = where(goodpix_ima_3539 eq 1 and nefd gt 0.)

help, where(nefd(index) lt 0.7)

print, 37.*(0.7/0.2)^2


help, donnees_red.cube

;;;;;
;;;;;

liste = findfile('../../apexdata/map_otf_xdr/T-091.F-0008-2013/otf_subscan_43041_*.xdr')

nefd_cube = fltarr(35,39,n_elements(liste))

for k = 0, n_elements(liste)-1 do begin restore, liste(k) & $
 print, "Subscan ", k & $
 for j = 0, 39-1 do begin & $
  for i = 0, 35-1 do begin & $
    nefd_cube(i,j,k) = (1/sqrt(40.))*stdev(donnees_red.cube(i,j,*)) & $
endfor

;

rel_speed = fltarr(n_elements(liste))

for k = 0, n_elements(liste)-1 do begin & $
 nefd_pix = nefd_cube(*,*,k) & $
 index = where(goodpix_ima_3539 eq 1 and nefd_pix gt 0.) & $
 id_good = where(nefd_pix(index) lt 0.7, count) & $
 rel_speed(k) = count/(37.*(0.7/0.2)^2) & $
 print, "Subscan: ", k, " Relative speed/SABOCA: ", rel_speed(k) & $ 
endfor

;

nefd_median = fltarr(35,39)


for j = 0, 39-1 do begin & $
 for i = 0, 35-1 do begin & $
  nefd_median(i,j) = median(nefd_cube(i,j,*)) & $
endfor

atv, nefd_median*goodpix_ima_3539

id_pos = where(goodpix_ima_3539 eq 1 and nefd_median gt 0.)			; 1030 valid pixels
print, median(nefd_median(id_pos))						; 0.71 Jy.s^1/2
print, min(nefd_median(id_pos))							; 0.38 Jy.s^1/2

artemis_rel_speed = total(1./(37.*(nefd_median(id_pos)/0.2)^2))			; 2.35


id_zero = where(nefd_median eq 0.)
nefd_median(id_zero) = -!values.f_nan

writefits, 'nefd_artemis_july13.fits', nefd_median*goodpix_ima_3539*1.e3

;  


min_nefd = min(nefd_median(id_pos))
max_nefd = max(nefd_median(id_pos))-0.1/2.


histogram_nefd = histogram(nefd_median(id_pos),min=min_nefd,max=max_nefd,binsize=0.1)

bin_line = min_nefd+findgen(n_elements(histogram_nefd))*0.1 + 0.5*0.1	;  middle point of nefd bin

; print, total(histogram_nefd)						; 891

plot, bin_line, histogram_nefd


;

traite_otf_map_main, scan_number= 43041, type = 'map', neptune_otf_43041_str, tau=1.54, /newreduc				;   Peak flux = 100.60 Jy/beam

;

neptune_otf_norcp_43041_str = neptune_otf_43041_str

image = neptune_otf_norcp_43041_str.image

mask = image*0
mask(104:210,100:206) = 1

gaussfit = gauss2dfit(image*mask,gaussfit_aparm,/tilt)										;  pfov = 3.8  echant = 3

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)										; -0.0241492
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)										; 99.0189
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-neptune_otf_norcp_43041_str.crpix1)*neptune_otf_norcp_43041_str.cdelt1*3600.	;  -0.06
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-neptune_otf_norcp_43041_str.crpix2)*neptune_otf_norcp_43041_str.cdelt2*3600.	; 1.5022607
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)				; -0.178331
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*neptune_otf_norcp_43041_str.cdelt2*3600.			; 8.63399
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*neptune_otf_norcp_43041_str.cdelt2*3600.			; 8.62020

;;;;
;;;;

traite_otf_map_main, scan_number= 43041, type = 'map', neptune_otf_43041_str, tau=1.54, /newreduc				;   Peak flux = 117.577 (no rcp, no off)   113.92		110.45 Jy/beam
																;  Peak flux = 119.027 (no rcp, but off)
image = neptune_otf_43041_str.image

mask = image*0
mask(149:390,165:346) = 1

gaussfit = gauss2dfit(image*mask,gaussfit_aparm,/tilt)										;  flat_saturn_best_jul13.xdr	flat_saturn_43011_jul13.xdr

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)										; -0.0199844		-0.0196192
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)										; 118.118     116.349  112.716	109.068    (3.87)
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-neptune_otf_43041_str.crpix1)*neptune_otf_43041_str.cdelt1*3600.		; 0.56916484 -0.46019749		-0.44120653
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-neptune_otf_43041_str.crpix2)*neptune_otf_43041_str.cdelt2*3600.		; 2.1278646   2.2231619 		 2.2210124
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)				; -0.522621  -0.526641		-0.523230
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*neptune_otf_43041_str.cdelt2*3600.				; 9.34726     9.48030		 9.53397
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*neptune_otf_43041_str.cdelt2*3600.				; 7.66284     7.69922		 7.73723

;;;;
;;;;


;goodpix_ima_saturn_arr2_jul13.xdr
traite_otf_map_main, scan_number= 43041, type = 'map', neptune_otf_arr2_43041_str, tau=1.54, /newreduc

image = neptune_otf_arr2_43041_str.image																						

mask = image*0
mask(115:243,209:303) = 1

gaussfit = gauss2dfit(image*mask,gaussfit_aparm,/tilt)										; flat_saturn_best_jul13.xdr	flat_saturn_43011_jul13.xdr

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)								  		; 0.144697		0.139093
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)								  		; 104.090		100.125     (3.87)
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-neptune_otf_arr2_43041_str.crpix1)*neptune_otf_arr2_43041_str.cdelt1*3600.  	; 0.63739295		0.64535310
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-neptune_otf_arr2_43041_str.crpix2)*neptune_otf_arr2_43041_str.cdelt2*3600.  	; 2.5316588		2.5398551
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)		  		; -0.269401		-0.268857
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*neptune_otf_arr2_43041_str.cdelt2*3600.		  	; 11.1421		11.2197
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*neptune_otf_arr2_43041_str.cdelt2*3600.		  	; 9.15140		9.17332

daz_2 = 0.63739295
del_2 = 2.5316588

;;;;;;

;goodpix_ima_saturn_arr3_jul13.xdr
traite_otf_map_main, scan_number= 43041, type = 'map', neptune_otf_arr3_43041_str, tau=1.54, /newreduc

image = neptune_otf_arr3_43041_str.image											

mask = image*0
mask(198:314,193:295) = 1

gaussfit = gauss2dfit(image*mask,gaussfit_aparm,/tilt)										; flat_saturn_43011_43618_43620_jul13.xdr

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)								  		; -0.129359
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)								  		; 120.204 
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-neptune_otf_arr3_43041_str.crpix1)*neptune_otf_arr3_43041_str.cdelt1*3600.  	; -0.22611730
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-neptune_otf_arr3_43041_str.crpix2)*neptune_otf_arr3_43041_str.cdelt2*3600.  	; 2.7355046
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)		  		; -0.504153
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*neptune_otf_arr3_43041_str.cdelt2*3600.		  	; 7.95913
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*neptune_otf_arr3_43041_str.cdelt2*3600.		  	; 7.11420

daz_3 = -0.22611730
del_3 =  2.7355046

;;;;;;

;goodpix_ima_saturn_arr6_jul13.xdr
traite_otf_map_main, scan_number= 43041, type = 'map', neptune_otf_arr6_43041_str, tau=1.54, /newreduc

image = neptune_otf_arr6_43041_str.image											

mask = image*0
mask(83:234,91:191) = 1

gaussfit = gauss2dfit(image*mask,gaussfit_aparm,/tilt)										; flat_saturn_43011_43618_43620_jul13.xdr

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)								  		; 0.00804829 0.00766962
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)								  		; 119.656   113.958
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-neptune_otf_arr6_43041_str.crpix1)*neptune_otf_arr6_43041_str.cdelt1*3600.  	; -0.24546258
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-neptune_otf_arr6_43041_str.crpix2)*neptune_otf_arr6_43041_str.cdelt2*3600.  	; 2.2023876
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)		  		; -0.451320
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*neptune_otf_arr6_43041_str.cdelt2*3600.		  	; 10.2981
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*neptune_otf_arr6_43041_str.cdelt2*3600.		  	; 7.70438

daz_6 = -0.24546258
del_6 = 2.2023876

;;;;;;

;goodpix_ima_saturn_arr7_jul13.xdr
traite_otf_map_main, scan_number= 43041, type = 'map', neptune_otf_arr7_43041_str, tau=1.54, /newreduc

image = neptune_otf_arr7_43041_str.image											

mask = image*0
mask(177:318,75:176) = 1

gaussfit = gauss2dfit(image*mask,gaussfit_aparm,/tilt)										; flat_saturn_43011_43618_43620_jul13.xdr

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)								  		;0.0423025 0.0422702 0.0402332
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)								  		; 118.646	118.372   112.731
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-neptune_otf_arr7_43041_str.crpix1)*neptune_otf_arr7_43041_str.cdelt1*3600.  	; 0.26924221 -1.1790788
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-neptune_otf_arr7_43041_str.crpix2)*neptune_otf_arr7_43041_str.cdelt2*3600.  	; 1.9738759   1.7229897
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)		  		; -2.28917
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*neptune_otf_arr7_43041_str.cdelt2*3600.		  	; 9.44003
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*neptune_otf_arr7_43041_str.cdelt2*3600.		  	; 7.74012

daz_7 = -1.1790788
del_7 = 1.7229897

;;;;;;

daz_3_rel_n = -0.863510
del_3_rel_n = 0.203846

daz_6_rel_n = -0.882856
del_6_rel_n = -0.329271

daz_7_rel_n = -1.81647
del_7_rel_n = -0.808669

;

daz_3_rel_av = (daz_3_rel + daz_3_rel_n)/2.	; -1.12685
del_3_rel_av = (del_3_rel + del_3_rel_n)/2.	;  0.383917

daz_6_rel_av = (daz_6_rel + daz_6_rel_n)/2.	; -0.853059
del_6_rel_av = (del_6_rel + del_6_rel_n)/2.	;  0.182794

daz_7_rel_av = (daz_7_rel + daz_7_rel_n)/2.	; -1.44687
del_7_rel_av = (del_7_rel + del_7_rel_n)/2.	; -0.232220

;

artemis350_dazdel2dxdy, daz_3_rel_av, del_3_rel_av, dx_3_rel_av, dy_3_rel_av		;   dx_3_rel_av = 1.17640, dy_3_rel_av = 0.182409

artemis350_dazdel2dxdy, daz_6_rel_av, del_6_rel_av, dx_6_rel_av, dy_6_rel_av		;   dx_6_rel_av = 0.871841, dy_6_rel_av = 0.0318849

artemis350_dazdel2dxdy, daz_7_rel_av, del_7_rel_av, dx_7_rel_av, dy_7_rel_av		;   dx_7_rel_av = 1.38456, dy_7_rel_av = -0.479938

;;;;;;

;;;;
;;;;

traite_otf_map_main, scan_number= 43041, type = 'map', neptune_otf_43041_str, tau=1.54, /do_rcp, /newreduc			;   Peak flux = 90.30 Jy/beam

;

neptune_otf_rcp_43041_str = neptune_otf_43041_str

image = neptune_otf_rcp_43041_str.image

mask = image*0
mask(104:210,100:206) = 1

gaussfit = gauss2dfit(image*mask,gaussfit_aparm,/tilt)
			
print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)										;  -0.0348545						
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)										; 88.5153
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-neptune_otf_rcp_43041_str.crpix1)*neptune_otf_rcp_43041_str.cdelt1*3600.	; 0.66246452
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-neptune_otf_rcp_43041_str.crpix2)*neptune_otf_rcp_43041_str.cdelt2*3600.	; 0.033137240
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)				; 0.464785
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*neptune_otf_rcp_43041_str.cdelt2*3600.			; 8.38974
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*neptune_otf_rcp_43041_str.cdelt2*3600.			; 10.0970

;;;;
;;;;

init_obs, scan_number= 43040, type = 'map', init_obs_43040_str								;   Single spiral scan (pointing)

traite_otf_map_main, scan_number= 43040, type = 'map', neptune_spiral_43040_str, tau=1.54, /newreduc
make_fits, neptune_spiral_43040_str, fileout='neptune_spiral_43040'

traite_otf_map_main, scan_number= 43040, type = 'map', neptune_spiral_43040_str_arr3, tau=1.54, /newreduc
make_fits, neptune_spiral_43040_str_arr3, fileout='neptune_spiral_43040_arr3'

traite_otf_map_main, scan_number= 43040, type = 'map', neptune_spiral_43040_str_arr2, tau=1.54, /newreduc
make_fits, neptune_spiral_43040_str_arr2, fileout='neptune_spiral_43040_arr2'

traite_otf_map_main, scan_number= 43040, type = 'map', neptune_spiral_43040_str_arr6, tau=1.54, /newreduc
make_fits, neptune_spiral_43040_str_arr6, fileout='neptune_spiral_43040_arr6'

traite_otf_map_main, scan_number= 43040, type = 'map', neptune_spiral_43040_str_arr7, tau=1.54, /newreduc
make_fits, neptune_spiral_43040_str_arr7, fileout='neptune_spiral_43040_arr7'

;

traite_otf_map_main, scan_number= 43040, type = 'decorrel', neptune_spiral_43040_str, tau=1.54, /newreduc
