; planet_artemis_rcp.pro: "Batch" IDL file 
;
; @obs1_artemis_config

; 350 microns focal plane : 64 x 36 = 2304 pixels in ArTeMiS350 but only 32 x 36 = 1152 pixels are used in 2013.
n_channel_x = 35      ; including 3 fake pixels between subarrays
n_channel_y = 39      ; including 3 fake pixels between subarrays

npix_eff = 35L*39L    ; including gaps

nx_chan = indgen(n_channel_x)#(transpose(intarr(n_channel_y))+1)
ny_chan = (intarr(n_channel_x)+1)#transpose(indgen(n_channel_y))

mask_jul13 = intarr(n_channel_x,n_channel_y)+1
mask_jul13(16:18,*) = 0
mask_jul13(*,18:20) = 0

mask_jul13_array3 = intarr(n_channel_x,n_channel_y)
mask_jul13_array3(19:*,0:17) = 1

ind_jul13 = where(mask_jul13 gt 0, nchan_eff)					;   1152 pixels

print, nchan_eff  			; Effective number of 350mu bolometer channels in 2013

; nchan_eff = 32*36	   		; Effective number of 350mu bolometer channels in 2013

;
traite_otf_map_main, scan_number= 43089, type = 'chmap', planet_ch_map_43089_str, tau=1.03
for j = 0, nchan_eff-1 do atv, planet_ch_map_43089_str.ch_map(*,*,ind_jul13(j))

planet_43089_gaussfit_apar = fltarr(7,npix_eff)
 

for j = 0, nchan_eff-1 do begin & i = ind_jul13(j) & $
   print, " Channel (32*36) ", j,  "     Channel (35*39) ", i & $   
   planet_43089_gaussfit = gauss2dfit(planet_ch_map_43089_str.ch_map(*,*,i),gaussfit_apar,/tilt) & $
   planet_43089_gaussfit_apar(*,i) = gaussfit_apar & $
   print, "Zero Level (Jy/beam) = ", planet_43089_gaussfit_apar(0,i) & $
   print, "Peak Intensity (Jy/beam) = ", planet_43089_gaussfit_apar(1,i) & $
   print, "Delta x  (arcsec) = ", (planet_43089_gaussfit_apar(4,i)-planet_ch_map_43089_str.crpix1)*planet_ch_map_43089_str.cdelt1*3600. & $
   print, "Delta y  (arcsec) = ", (planet_43089_gaussfit_apar(5,i)-planet_ch_map_43089_str.crpix2)*planet_ch_map_43089_str.cdelt2*3600. & $
   print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", planet_43089_gaussfit_apar(6,i) & $
   print, "Maj FWHM (arcsec) = ", planet_43089_gaussfit_apar(2,i)*sqrt(8.*alog(2.))*planet_ch_map_43089_str.cdelt2*3600. & $
   print, "Min FWHM (arcsec) = ", planet_43089_gaussfit_apar(3,i)*sqrt(8.*alog(2.))*planet_ch_map_43089_str.cdelt2*3600. & $
   print, "       " & $
endfor

conv_planet_43089 = fltarr(npix_eff)
flux_planet = 205.										; Peak flux density of planet in Jy/beam on date of observation  (**To be edited**)
conv_planet_43089(*) = init_obs_43089_str.conv*planet_43089_gaussfit_apar(1,*)/flux_planet
conv_planet_43089 = reform(conv_planet_43089,n_channel_x,n_channel_y)				; 3e-6 -> 2e-5 (with atmospheric correction)

peak_flux_arr_planet_43089 = fltarr(npix_eff)									
peak_flux_arr_planet_43089(*) = planet_43089_gaussfit_apar(1,*)
peak_flux_arr_planet_43089 = reform(peak_flux_arr_planet_43089,n_channel_x,n_channel_y)			

ind_arr2 = where(goodpix_ima_3539_arr2)
ind_arr3 = where(goodpix_ima_3539_arr3)
ind_arr6 = where(goodpix_ima_3539_arr6)
ind_arr7 = where(goodpix_ima_3539_arr7)

print, median(peak_flux_arr_planet_43089(ind_arr2))			; 186.592
print, median(peak_flux_arr_planet_43089(ind_arr3))			; 205.497
print, median(peak_flux_arr_planet_43089(ind_arr6))			; 155.544
print, median(peak_flux_arr_planet_43089(ind_arr7))			; 176.391

print, median(conv_planet_43089(ind_arr2))				; 9.89930e-06
print, median(conv_planet_43089(ind_arr3))				; 1.09023e-05
print, median(conv_planet_43089(ind_arr6))				; 8.25208e-06
print, median(conv_planet_43089(ind_arr7))				; 9.35809e-06

;

flat_planet_43089 = fltarr(npix_eff)
nx_ref_pix = 19  ; 15							; Reference pixel for Calibration (19,21)  Conv = 1.08759e-05
ny_ref_pix = 21  ; 17
;;print, where(nx_chan eq 15 and ny_chan eq 17)
; 
n_ref_pix = 754  ;  610							;  pixel de reference dans la matrice ArTeMiS350_2013 (35x39) : (15,17) <--> 610 (IDL)
;
peak_ref = planet_43089_gaussfit_apar(1,n_ref_pix)			;  Peak intensity in map made with reference bolometer channel
flat_planet_43089(*) = planet_43089_gaussfit_apar(1,*)/peak_ref
flat_planet_43089 = reform(flat_planet_43089,n_channel_x,n_channel_y)
flat_field = flat_planet_43089						;  0.2 -> 10

;

goodpix_ima = fltarr(n_channel_x,n_channel_y)+1.
ind = where(flat_field lt 0.2 or flat_field gt 5.)
goodpix_ima(ind) = 0.

;

daz_planet = fltarr(n_channel_x,n_channel_y)
del_planet = fltarr(n_channel_x,n_channel_y)

daz_planet(*) = -(planet_43089_gaussfit_apar(4,*)-planet_ch_map_43089_str.crpix1)*planet_ch_map_43089_str.cdelt1*3600.
del_planet(*) = -(planet_43089_gaussfit_apar(5,*)-planet_ch_map_43089_str.crpix2)*planet_ch_map_43089_str.cdelt2*3600.

daz_planet0 = daz_planet(19,21) ;  daz_planet(15,17)			;  Reference pixel = (15,17) in 35*39 grid
del_planet0 = del_planet(19,21) ; del_planet(15,17)

daz_planet = daz_planet-daz_planet0
del_planet = del_planet-del_planet0

;;;;;;;;;;;;;;;elev = 39.3	;  deg    Mean Elevation of planet during scan 43089			NB:  No Nasmyth rotation at Cassegrain focus --> elev does not matter

;;;;;;;;;;;;;;;ROT_dazdel2dxdy, daz_planet, del_planet, elev, dx_planet, dy_planet

artemis350_dazdel2dxdy, daz_planet, del_planet, dx_planet_rot, dy_planet_rot

;

dx_planet = daz_planet
dy_planet = del_planet

atv, dx_planet
atv, dy_planet

goodpix_ima(1,27) = 0.
goodpix_ima(6,38) = 0.
goodpix_ima(19,15) = 0.			; noisy
goodpix_ima(34,17) = 0.
goodpix_ima(12,14) = 0.
goodpix_ima(3,12) = 0.
goodpix_ima(3,6) = 0.
goodpix_ima(5,4) = 0.
goodpix_ima(3,4) = 0.
goodpix_ima(6,3) = 0.
goodpix_ima(34,3) = 0.
goodpix_ima(3,2) = 0.
goodpix_ima(1,1) = 0.
goodpix_ima(32,0) = 0.
goodpix_ima(32,1) = 0.
goodpix_ima(1,0) = 0.

atv, dx_planet*goodpix_ima
atv, dy_planet*goodpix_ima

;

dx_rcp = dx_planet
dy_rcp = dy_planet


nxchan = indgen(n_channel_x)#(transpose(intarr(n_channel_y))+1)
nychan = (intarr(n_channel_x)+1)#transpose(indgen(n_channel_y))

pix = 3.9
alpha = 0.

index = where(goodpix_ima eq 1)

;;;;;;;;dpos_planet  = [dx_planet(index),dy_planet(index)]
dpos_planet  = [-dx_planet(index),dy_planet(index)]
dchan   = [(nxchan-nx_ref_pix)(index),(nychan-ny_ref_pix)(index)]
dchan_t = [(nychan-ny_ref_pix)(index),-(nxchan-nx_ref_pix)(index)]


print, "Simple estimate of the pixel size (arcsec) : ", correlate(dchan,dpos_planet,/covariance)/(sigma(dchan))^2	   ; Simple estimate of the pixel size (arcsec):3.72960  ;  3.54900

dchan_var = float([dchan,dchan_t])		;  Vector of "independent variables"
dpos_var  = [dpos_planet,dpos_planet]		;  Vector of "dependent variables"

chi_red = 0.
apar = [pix, alpha]
rms = apar*0.
weights = dpos_var*0.+1.
;
.run rcp_fun
;rcp_fit = LMFIT(dchan_var,dpos_var,APAR,SIGMA=RMS,CHISQ=chi,FUNCTION_NAME='rcp_fun')
rcp_fit = CURVEFIT(dchan_var,dpos_var,Weights,APAR,RMS,CHISQ=chi_red,FUNCTION_NAME='rcp_fun')
;
print, "Pixel size (arcsec) : ", apar(0), " +- ", rms(0)								   ; 3.73277 +-    0.00137876  ;  3.54502 +-    0.00142685   arcsec
print, "Rotation angle of the array (deg) : ", apar(1)*180./!pi," +- ", rms(1)*180./!pi					   ;  -9.57760 +-  0.0214567 deg  -11.0403 +-     0.0234854     deg


;;;;;;;;
;;;;;;;;	Saving rcp results in 350mu focal plane reference frame (64 x 36 grid)
;;;;;;;;

goodpix_ima_3539 = goodpix_ima				;    35*39 grid  (ArTeMiS350 Jul2013, counting gaps between subarrays)
flat_field_3539 = flat_field				;    35*39 grid  (ArTeMiS350 Jul2013)
dx_rcp_3539 = dx_rcp					;    35*39 grid  (ArTeMiS350 Jul2013)
dy_rcp_3539 = dy_rcp					;    35*39 grid  (ArTeMiS350 Jul2013)

; 
goodpix_ima = focal2img350(goodpix_ima_3539)		;    64*36 grid  (BoA)
flat_field  = focal2img350(flat_field_3539)		;    64*36 grid
dx_rcp	    = focal2img350(dx_rcp_3539)			;    64*36 grid
dy_rcp	    = focal2img350(dy_rcp_3539)			;    64*36 grid

;

nchan_350 = 64*36

;for i = 0, nchan_350-1 do print, i+1, " ", flat_field(i), "  ", goodpix_ima(i), " ", dx_rcp(i), "  ", dy_rcp(i)

openw, 1, work_dir+'Calib_partemis/artemis_planet_43089_rcp.dat'
for i = 0, nchan_350-1 do printf, 1, i+1, " ", flat_field(i), "  ", goodpix_ima(i), " ", dx_rcp(i), "  ", dy_rcp(i)
close, 1

;

save, file = work_dir+'Calib_partemis/rcp_planet_43089_jul13.xdr', dx_rcp, dy_rcp, /verb

save, file = work_dir+'Calib_partemis/flat_planet_43089_jul13.xdr', flat_field , /verb

save, file =  work_dir+'Calib_partemis/goodpix_ima_planet_43089_jul13.xdr', goodpix_ima

 
;

restore, work_dir+'Calib_partemis/flat_planet_43089_jul13.xdr', /verb              ; <-- flat_field
restore, work_dir+'Calib_partemis/goodpix_ima_planet_43089_jul13.xdr', /verb       ; <-- goodpix_ima
restore, work_dir+'Calib_partemis/rcp_planet_43089_jul13.xdr', /verb		  ; <-- dx_rcp, dy_rcp

;;;;;;;;;;;;

restore, work_dir+'Calib_partemis/goodpix_ima_00001.xdr', /verb       		; <-- goodpix_ima
restore, work_dir+'Calib_partemis/rcp_00001.xdr', /verb		  		; <-- dx_rcp, dy_rcp		64*36

;
goodpix_ima_boa = goodpix_ima
dx_rcp_boa = dx_rcp
dy_rcp_boa = dy_rcp

; 
goodpix_ima = img2focal350(goodpix_ima_boa)		;    35*39 grid  (IDL ArTeMiS350 Jul2013, counting gaps between subarrays)
dx_rcp	    = img2focal350(dx_rcp_boa)			;    35*39 grid  
dy_rcp	    = img2focal350(dy_rcp_boa)			;    35*39 grid

pix = 3.9
alpha = 0.

index = where(goodpix_ima eq 1)

dpos  = [-dx_rcp(index),dy_rcp(index)]
dchan   = [(nxchan-nx_ref_pix)(index),(nychan-ny_ref_pix)(index)]
dchan_t = [(nychan-ny_ref_pix)(index),-(nxchan-nx_ref_pix)(index)]

print, "Simple estimate of the pixel size (arcsec) : ", correlate(dchan,dpos,/covariance)/(sigma(dchan))^2	   ; Simple estimate of the pixel size (arcsec): 3.83664



dchan_var = float([dchan,dchan_t])		;  Vector of "independent variables"
dpos_var  = [dpos,dpos]				;  Vector of "dependent variables"

chi_red = 0.
apar = [pix, alpha]
rms = apar*0.
weights = dpos_var*0.+1.
;
.run rcp_fun
;rcp_fit = LMFIT(dchan_var,dpos_var,APAR,SIGMA=RMS,CHISQ=chi,FUNCTION_NAME='rcp_fun')
rcp_fit = CURVEFIT(dchan_var,dpos_var,Weights,APAR,RMS,CHISQ=chi_red,FUNCTION_NAME='rcp_fun')
;
print, "Pixel size (arcsec) : ", apar(0), " +- ", rms(0)								   ;  3.83305 +-    0.00136464  arcsec
print, "Rotation angle of the array (deg) : ", apar(1)*180./!pi," +- ", rms(1)*180./!pi					   ; -10.1024 +-   0.0207131    deg

;;;;;;;
;;;;;;;



 conv = 1.10005e-05				; conv_planet_43089(15,17)
; restore, '/Users/pandre/kosma/artemis/Calib_partemis/flat_mars_24822_22may09.xdr', /verb		; --> restoring flat_field
; flat_field(0,15) = 1.
;
; init_obs, scan_number= 43090, type = 'map', init_obs_43090_str
; noise_fft_skydip, 43090, sky_noise_str, /nopowermap, /decorrel
;
; init_obs, scan_number= 43042, type = 'map', init_obs_43042_str
; noise_fft_skydip, 43042, sky_noise_str, /nopowermap, /decorrel
;
;;;;; goodpix_ima_3539 = goodpix_ima_3539(Saturn 43011) ;  flat_field_3539 = flat_field_3539(Saturn 43011)
;
; index = where(goodpix_ima_3539 eq 1 and sky_noise_str(0).rms_noise_corr gt 0. and mask_jul13_array3 eq 1)
; index = where(goodpix_ima_3539 eq 1 and sky_noise_str(0).rms_noise_corr gt 0.)
;
; for i = 0, 5 do print, "Power = ", sky_noise_str(i).mean_level_av,"  ", sky_noise_str(i).scanname, "   El = ", sky_noise_str(i).elevatio
; for i = 0, 5 do print, "Median NEFD = ", median((exp(0.8/sin(50*!pi/180.))/sqrt(40.))*sky_noise_str(i).rms_noise_corr/flat_field_3539/conv)
; for i = 0, 5 do print, "Min NEFD = ", min((exp(0.8/sin(50*!pi/180.))/sqrt(40.))*sky_noise_str(i).rms_noise_corr/flat_field_3539/conv)
;
; for i = 0, 5 do print, "Median NEFD = ", median((1/sqrt(40.))*sky_noise_str(i).rms_noise_corr(index)/flat_field_3539(index)/conv)
; for i = 0, 5 do print, "Min NEFD = ", min((1/sqrt(40.))*sky_noise_str(i).rms_noise_corr(index)/flat_field_3539(index)/conv)
;
;;;;;;;;;;;; ind_noi0 = index(where(sky_noise_str(0).rms_noise_corr(index) eq 0.0))
;
; atv, (1/sqrt(40.))*sky_noise_str(0).rms_noise_corr*goodpix_ima_3539/flat_field_3539/conv
;
; help, where((1/sqrt(40.))*sky_noise_str(0).rms_noise_corr(index)*goodpix_ima_3539(index)/flat_field_3539(index)/conv lt 0.7)
;;;;;;
;;;;;;

int_max = fltarr(35,39)
;
for j = 0, 38 do begin & $
for i = 0, 34 do begin & $
int_max(i,j) = max(donnees_red.cube(i,j,*)) & $
endfor

;;;;;;
;;;;;;

toto = mrdfits('/Users/pandre/kosma/artemis/Calib_partemis/ACQ_130718_134057.fits',1)
help, toto, /str
time = (toto.mjd-toto(0).mjd)*24.*3600.d0		; sec traite_otf_map_main, scan_number= 43089, type = 'chmap', planet_ch_map_43089_str, tau=1.03
;
plot, toto(*).data(31,17)
plot, time, toto(*).data(31,17)
;
ind_abs = where(toto(*).data(31,17) gt -0.18)
;
plot, time(ind_abs), toto(ind_abs).data(31,17)

;

print, (1/sqrt(40.))*stdev(toto(ind_abs).data(31,17))/conv


;;;;
;;;;

init_obs, scan_number= 43089, type = 'map', init_obs_43089_str

traite_otf_map_main, scan_number= 43089, type = 'map', uranus_otf_43089_str, tau=1.03, /newreduc	;   Peak flux (echant = 5) = 171.263	;   Peak flux (echant = 3) = 165.324   166.65 Jy/beam

image = uranus_otf_43089_str.image									;   161.518(154.277) (-)  160.518(152.193) (+)
													;   166.151(157.437) (-)  172.345(165.121) (+)

													;   175.235 (echant 5, norcp but off_arr, base_rad = 25.)

gaussfit = gauss2dfit(image,gaussfit_aparm,/tilt)

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)								  ;-0.337791	-0.313395	-0.321853         	   ; -0.374926
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)								  ;180.886 (off) 180.294  174.870 (no_off) 164.276	 165.318    (echant = 5)   ; 159.420158 (echant = 3)
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-uranus_otf_43089_str.crpix1)*uranus_otf_43089_str.cdelt1*3600.  ;0.61996088	 1.9003158 	 1.8795532   		   ; 0.906266890
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-uranus_otf_43089_str.crpix2)*uranus_otf_43089_str.cdelt2*3600.  ;1.3045690	-0.35568788 	-0.41314501 		   ; 0.80144627
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)		  ;-0.364940	-0.362511   	-0.359811		   ; -0.374444
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*uranus_otf_43089_str.cdelt2*3600.		  ;10.7887	10.9038      	10.6449	     	   	   ; 10.3356
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*uranus_otf_43089_str.cdelt2*3600.		  ;8.31683	8.48839     	8.31433	     	   	   ; 8.26247


;

;goodpix_ima_saturn_arr2_jul13.xdr
traite_otf_map_main, scan_number = 43089, type = 'map', uranus_otf_arr2_43089_str, tau=1.03, /newreduc

image = uranus_otf_arr2_43089_str.image																						

gaussfit = gauss2dfit(image,gaussfit_aparm,/tilt)										; flat_saturn_43011_jul13.xdr

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)								  		; 0.525462  0.507664		0.412648
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)								  		; 180.783   174.672    (3.87)	178.952
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-uranus_otf_arr2_43089_str.crpix1)*uranus_otf_arr2_43089_str.cdelt1*3600.  	; 1.6073966		1.2668584
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-uranus_otf_arr2_43089_str.crpix2)*uranus_otf_arr2_43089_str.cdelt2*3600.  	; 0.84970700		0.58194383
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)		  		; -0.310730		-0.342765
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*uranus_otf_arr2_43089_str.cdelt2*3600.		  	; 12.7826		11.3894
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*uranus_otf_arr2_43089_str.cdelt2*3600.		  	; 8.45464		7.94774

daz_2 = 1.6073966
del_2 = 0.84970700

;;;;;;

;goodpix_ima_saturn_arr3_jul13.xdr
traite_otf_map_main, scan_number = 43089, type = 'map', uranus_otf_arr3_43089_str, tau=1.03, /newreduc

image = uranus_otf_arr3_43089_str.image																						

gaussfit = gauss2dfit(image,gaussfit_aparm,/tilt)										; flat_saturn_43011_43618_43620_jul13.xdr

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)								  		; -0.0328110		-0.144635
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)								  		; 201.025 (3.87)	199.922
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-uranus_otf_arr3_43089_str.crpix1)*uranus_otf_arr3_43089_str.cdelt1*3600.  	; 0.21720595		1.2383483
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-uranus_otf_arr3_43089_str.crpix2)*uranus_otf_arr3_43089_str.cdelt2*3600.  	;  1.4136962		-0.42360893
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)		  		; -0.304339		-0.342102
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*uranus_otf_arr3_43089_str.cdelt2*3600.		  	; 10.6879		10.0094
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*uranus_otf_arr3_43089_str.cdelt2*3600.		  	; 8.34954		7.98457

daz_3 = 0.21720595
del_3 = 1.4136962

;;;;;;

;goodpix_ima_saturn_arr6_jul13.xdr
traite_otf_map_main, scan_number = 43089, type = 'map', uranus_otf_arr6_43089_str, tau=1.03, /newreduc

image = uranus_otf_arr6_43089_str.image												

gaussfit = gauss2dfit(image,gaussfit_aparm,/tilt)										; flat_saturn_43011_43618_43620_jul13.xdr

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)								  		; 0.0110872  0.0105370	  0.0623042		 0.0386615
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)								  		; 170.328  162.217  (3.87) 163.763 (3.83)	 148.143 (3.87)
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-uranus_otf_arr6_43089_str.crpix1)*uranus_otf_arr6_43089_str.cdelt1*3600.  	; 0.78413589	  0.44656612		 0.79356052
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-uranus_otf_arr6_43089_str.crpix2)*uranus_otf_arr6_43089_str.cdelt2*3600.  	; 1.5445661	  1.1386089		 1.5291183
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)		  		; -0.488714	  -0.336436		 -0.482129
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*uranus_otf_arr6_43089_str.cdelt2*3600.		  	; 11.0816	  10.7136		 11.1680 
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*uranus_otf_arr6_43089_str.cdelt2*3600.		  	; 8.30447	  8.40666		 8.33645 

daz_6 = 0.78413589
del_6 = 1.5445661

;;;;;;

;goodpix_ima_saturn_arr7_jul13.xdr
traite_otf_map_main, scan_number = 43089, type = 'map', uranus_otf_arr7_43089_str, tau=1.03, /newreduc

image = uranus_otf_arr7_43089_str.image												

gaussfit = gauss2dfit(image,gaussfit_aparm,/tilt)										; flat_saturn_43011_43618_43620_jul13.xdr

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)								  		; 0.05182100.0493900		-0.000372577
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)								  		; 174.296  165.996 (3.87)	159.690
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-uranus_otf_arr7_43089_str.crpix1)*uranus_otf_arr7_43089_str.cdelt1*3600.  	; 0.53013172			2.5610786
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-uranus_otf_arr7_43089_str.crpix2)*uranus_otf_arr7_43089_str.cdelt2*3600.  	; 1.1939360			-0.98600372
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)		  		; -0.336826			-0.275245
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*uranus_otf_arr7_43089_str.cdelt2*3600.		  	; 9.62748			9.27223
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*uranus_otf_arr7_43089_str.cdelt2*3600.		  	; 7.96254			7.81598

daz_7 = 0.53013172
del_7 = 1.1939360

;;;;;;

daz_3_rel = -1.39019
del_3_rel = 0.563989

daz_6_rel = -0.823261
del_6_rel =  0.694859

daz_7_rel = -1.07726
del_7_rel =  0.344229

;;;;;;


restore, '/Users/pandre/kosma/artemis/apexdata/map_otf_xdr/T-091.F-0008-2013/otf_subscan_43089_50.xdr', /verb

for i = 0, 436 do atv, donnees_red.cube(*,*,i)*init_obs_43089_str.goodpix_ima


uranus_otf_norcp_43089_str = uranus_otf_43089_str

image = uranus_otf_norcp_43089_str.image

gaussfit = gauss2dfit(image,gaussfit_aparm,/tilt)

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)										; -0.375580
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)										; 158.758
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-uranus_otf_norcp_43089_str.crpix1)*uranus_otf_norcp_43089_str.cdelt1*3600.	; 0.94727220
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-uranus_otf_norcp_43089_str.crpix2)*uranus_otf_norcp_43089_str.cdelt2*3600.	; 0.81538925
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)				;  -0.339212
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*uranus_otf_norcp_43089_str.cdelt2*3600.			; 10.2780
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*uranus_otf_norcp_43089_str.cdelt2*3600.			; 8.33497

;;

init_obs, scan_number= 43089, type = 'map', init_obs_43089_str

traite_otf_map_main, scan_number= 43089, type = 'map', uranus_otf_43089_str, tau=1.03, /do_rcp, /newreduc  ; Peak flux=166.3 (echant=3) 166.619 (echant=5, 1.05) 167.742 Jy/beam (echant=5)

uranus_otf_rcp_43089_str = uranus_otf_43089_str

image = uranus_otf_rcp_43089_str.image

gaussfit = gauss2dfit(image,gaussfit_aparm,/tilt)

print, "Zero Level (Jy/beam) = ", gaussfit_aparm(0)										; -0.160538    --> -0.185927	--> -0.173952
print, "Peak Intensity (Jy/beam) = ", gaussfit_aparm(1)										; 157.153      ->    157.316	-->  157.918
print, "Delta x  (arcsec) = ", (gaussfit_aparm(4)-uranus_otf_rcp_43089_str.crpix1)*uranus_otf_rcp_43089_str.cdelt1*3600.	; 1.4129443    -->   1.3439170	--> 1.3905862
print, "Delta y  (arcsec) = ", (gaussfit_aparm(5)-uranus_otf_rcp_43089_str.crpix2)*uranus_otf_rcp_43089_str.cdelt2*3600.	; -0.50393659  --> -0.45028035	-->-0.42731066
print, "Position angle of major axis measured counterclockwise from x axis (deg) = ", gaussfit_aparm(6)				; -0.0762457  --> 0.245535	--> 0.323422
print, "Maj FWHM (arcsec) = ", gaussfit_aparm(2)*sqrt(8.*alog(2.))*uranus_otf_rcp_43089_str.cdelt2*3600.			; 9.24249     --> 9.20450	--> 9.20172
print, "Min FWHM (arcsec) = ", gaussfit_aparm(3)*sqrt(8.*alog(2.))*uranus_otf_rcp_43089_str.cdelt2*3600.			; 9.05963     --> 9.11445	--> 8.95231


;;;;
;;;;

init_obs, scan_number= 43088, type = 'map', init_obs_43088_str								;   Single spiral scan (pointing)

traite_otf_map_main, scan_number= 43088, type = 'map', uranus_spiral_43088_str, tau=1.03, /newreduc			;   Peak flux = 164.7 Jy/beam


;;;;;;

traite_otf_map_main, scan_number= 43088, type = 'decorrel', uranus_spiral_43088_str, tau=1.03, /newreduc
