pro slice_otf, datastr_in, dirdef, proj_name, keep=keep


; keep = 1 : on elimine les transitions entre scans
; keep = 2 : on garde toutes les donnees, meme les transitions entre scans 

command = datastr_in.obslog.command				;  recuperation de datastr_in additionnelles dans les OBSLOG
if strpos(command,'angle=') ne -1L then begin			; 'angle=' is contained in command
  command = strmid(command,strpos(command,'angle='))
endif else begin
  command = -1
endelse  
if ((size(command))(1) eq 7) then begin 			;  command is a string (i.e. strmid did not return -1)
	angle = (strsplit(command,',',/extract))(0)
	angle =  float(strmid(angle,strpos(angle,'=')+1))	; Rotation angle (deg) of scanning direction relative to Az axis
endif else begin
	angle = 0.0
endelse

angle = angle*!pi/180d0

scan_off = cos(angle)*datastr_in.datapar.longoff + sin(angle)*datastr_in.datapar.latoff
cross_scan_off = -sin(angle)*datastr_in.datapar.longoff + cos(angle)*datastr_in.datapar.latoff


;------------------ on entre dans le vif du sujet ------------------------------------------

;ind = indgen(n_elements(datastr_in.datapar.lst))
ind = lindgen(n_elements(datastr_in.datapar.lst))

; recherche des points pour lesquels la vitesse de scan est nominale
;toto= deriv(datastr_in.datapar.lst, datastr_in.datapar.longoff)
toto= deriv(datastr_in.datapar.lst, scan_off)
;titi= median(deriv(datastr_in.datapar.lst, scan_off),10)
ii = where((abs(toto*3600) gt 0.9*datastr_in.OTFVLAM) and (abs(toto*3600) lt 1.1*datastr_in.OTFVLAM))

longoff = scan_off							;  datastr_in.datapar(ii).longoff
latoff = cross_scan_off							;  datastr_in.datapar(ii).latoff
lst = datastr_in.datapar(ii).lst
ind = ind(ii)

;recherche des points pour lesquels l'ecart en lst est le temps de pose
dlst = deriv(lst) 
;iii = where(dlst gt 0.02 and dlst lt 0.03)
iii = where(dlst lt 0.03)

longoff = scan_off(iii) 						;  longoff(iii)
;latoff = cross_scan_off(iii)  						;  latoff(iii)
latoff = median(cross_scan_off(iii),40)
lst = lst(iii)
ind = ind(iii)

dlatoff = abs(latoff(0:n_elements(latoff)-2)-latoff(1:*))
;j = where(dlatoff*3600 gt 2)
j = where(dlatoff*3600 gt datastr_in.obslog.map.ystep/4.) 

nscans = n_elements(j)+1

debut=[0,ind(j+1)]
fin = [ind(j),max(ind)-1]

; Si on veut tout garder :
if keep eq 2 then begin
	debut=[0,ind(j)+1]
	fin = [ind(j),max(ind)-1]
endif



; On extrait les donnees qui nous interessent et on les sauve dans les fichiers adequat

print, "number of subscans", nscans

for k=0,nscans-1 do begin

	reduce_donneestruct, datastr_in, fin(k)-debut(k)+1, datastr, /cube_orig
	datastr.cube = datastr_in.cube(*,*,debut(k):fin(k))
	datastr.azim = datastr_in.azim(debut(k):fin(k))
	datastr.elev = datastr_in.elev(debut(k):fin(k))
	datastr.rota = datastr_in.rota(debut(k):fin(k))
	datastr.poschop = datastr_in.poschop(debut(k):fin(k))
	datastr.chopbeam = datastr_in.chopbeam(debut(k):fin(k))
	datastr.lst = datastr_in.lst(debut(k):fin(k))
	datastr.datapar = datastr_in.datapar(debut(k):fin(k))
	datastr.cube_orig = datastr_in.cube_orig(*,*,debut(k):fin(k))
	
	datastr.elevatio = median(datastr.datapar.elevatio)
	
	datastr.subscan = strtrim(string(k+1), 2)
	datastr.nobs = fix(nscans)
	datastr.nsubs = fix(nscans)
	
	save, filename=dirdef + proj_name + '_' + strtrim(string(datastr.scannum),2) + '_' + datastr.subscan + '.xdr', datastr, /xdr
	print, 'SLICE_OTF : writing basic_xdr file for subscan # ' + datastr.subscan
	
endfor

; Pour test de validite
;latmean = fltarr(nscans) & latrms = fltarr(nscans)
;for k=0,nscans-1 do begin latmean(k) = mean(latoff(debut(k):fin(k))) & latrms(k) = sigma(latoff(debut(k):fin(k)))

return
end

