pro unzip_artemis, scan, work_dir
;
; Usage (example): unzip_artemis, '60078', "/Users/pandre/kosma/artemis/"
;
;  Archive filename: ESO-APEX-58809-2013-09-10-E-090.C-0894A-2012.fits

if n_params() ne 2 then begin
	print, 'Calling sequence : '
	print, '         UNZIP_ARTEMIS, scan_number, artemis_work_dir'
	print, '               artemis_work_dir : folder containing apexdata folder, terminated by /'
	print, '               archive fits file must be in rawdata folder'
	return
endif


file = findfile(work_dir + 'apexdata/rawdata/*-APEX-'+strtrim(scan, 2)+'-*.*.fits', count=count)

if count eq 0 then begin
	print, 'UNZIP_ARTEMIS : Archive file not found'
	return
endif

if count ne 1 then begin
	print, 'UNZIP_ARTEMIS : Too many files too unzip'
	print, file
	return
endif

file = file(0)

; 2013-09-04T15-01-59.120-84508-APEX-57276-2013-09-02-O-091.F-9300A-2013.fits

pos0 = strpos(file, '-APEX-')
pos1 = strpos(file, '.fits')

Obs = strmid(file, pos0+1, pos1 - pos0-1)

bidon = findfile(work_dir + 'apexdata/rawdata/' + obs, count=count)

if count ne 0 then begin
	print, 'UNZIP_ARTEMIS : Destination folder already exists - UNZIP cancelled'
	print, ''
	return
endif

spawn, 'mkdir ' + work_dir + 'apexdata/rawdata/' + obs

scan = mrdfits(file, 1, header)

mwrfits, scan, work_dir + 'apexdata/rawdata/' + obs + '/' + 'SCAN.fits', header

nsubs = fxpar(header, 'NSUBS')

febepar = mrdfits(file, 2, header)
mwrfits, febepar, work_dir + 'apexdata/rawdata/' + obs + '/' + 'ARTEMIS350-BEAR1-FEBEPAR.fits', header

for i=0, nsubs-1 do begin
	subscandir = work_dir + 'apexdata/rawdata/' + obs + '/' + strtrim(i+1, 2)
	spawn, 'mkdir ' + subscandir
	
	datapar = mrdfits(file, 4*(i+1)-1, header)
	mwrfits, datapar, subscandir + '/' + 'ARTEMIS350-BEAR1-DATAPAR.fits', header
	
	arraydata = mrdfits(file, 4*(i+1)-1+1, header)
	mwrfits, arraydata, subscandir + '/' + 'ARTEMIS350-BEAR1-ARRAYDATA-2.fits', header
	
	arraydata = mrdfits(file, 4*(i+1)-1+2, header)
	mwrfits, arraydata, subscandir + '/' + 'ARTEMIS350-BEAR1-ARRAYDATA-1.fits', header
	
	monitor = mrdfits(file, 4*(i+1)-1+3, header)
	mwrfits, monitor, subscandir + '/' + 'MONITOR.fits', header
	
endfor

return
end
